@@ -305,7 +305,6 @@ void App_Glom::init_menus()
     "        <menuitem action='GlomAction_Menu_Developer_Database_Preferences' />"
     "        <menuitem action='GlomAction_Menu_Developer_Fields' />"
     "        <menuitem action='GlomAction_Menu_Developer_Relationships' />"
-    "        <menuitem action='GlomAction_Menu_Developer_RelationshipsOverview' />"
     "        <menuitem action='GlomAction_Menu_Developer_Layout' />"
     "        <menuitem action='GlomAction_Menu_Developer_Users' />"
     "        <menuitem action='GlomAction_Menu_Developer_Reports' />"
@@ -314,6 +313,8 @@ void App_Glom::init_menus()
     "  </menubar>"
     "</ui>";
 
+/*  "        <menuitem action='GlomAction_Menu_Developer_RelationshipsOverview' />" */
+
   //Add menu:
   add_ui_from_string(ui_description);
 
