@@ -181,6 +181,7 @@ bool Box_Data_Details::fill_from_database()
 
   try
   {
+
     //TODO: This should keep the connection open, so we don't need to 
     //reconnect many times..
     sharedptr<SharedConnection> sharedconnection = connect_to_server();
@@ -203,8 +204,8 @@ bool Box_Data_Details::fill_from_database()
       if(table_privs.m_view)
       {
         //Add extra possibly-non-visible columns that we need:
-        LayoutItem_Field layout_item;
-        layout_item.m_field = m_field_primary_key;
+        sharedptr<LayoutItem_Field> layout_item(new LayoutItem_Field);
+        layout_item->m_field = m_field_primary_key;
         fieldsToGet.push_back(layout_item);
 
         //g_warning("primary_key name = %s", m_field_primary_key.get_name().c_str());
@@ -231,11 +232,11 @@ bool Box_Data_Details::fill_from_database()
             //Get field values to show:
             for(int i = 0; i < cols_count; ++i)
             {
-              const LayoutItem_Field& layout_item = fieldsToGet[i];
+              sharedptr<LayoutItem_Field> layout_item = fieldsToGet[i];
 
               //Field value:
               Gnome::Gda::Value value = result->get_value_at(i, row_number);
-              m_FlowTable.set_field_value(layout_item, value);
+              m_FlowTable.set_field_value(*layout_item, value);
             }
           }
         }
@@ -343,16 +344,7 @@ void Box_Data_Details::set_entered_field_data(const LayoutItem_Field& field, con
 
 Gnome::Gda::Value Box_Data_Details::get_primary_key_value_selected()
 {
-
-  Glib::ustring strResult;
-/* TODO_port.
-  guint uiRow = 0;
-  bool bPresent = get_field_primary_key(uiRow);
-  if(bPresent)
-    strResult = m_AddDel.get_value(uiRow);
-
-*/
-  return Gnome::Gda::Value(strResult);
+  return m_primary_key_value;
 }
 
 /*
@@ -539,12 +531,14 @@ void Box_Data_Details::on_flowtable_field_edited(const LayoutItem_Field& layout_
     //const Field& field = layout_field.m_field;
 
     //Set the value in all instances of this field in the layout (The field might be on the layout more than once):
-    m_FlowTable.set_field_value(layout_field, field_value);
+    if(layout_field.m_field.get_glom_type() != Field::TYPE_IMAGE) //TODO For now, don't do this for images, because the ImageGlom widget expects a broken GdaValue, because gda_value_get_binary() needs to be fixed.
+      m_FlowTable.set_field_value(layout_field, field_value);
 
     //Update the field in the record (the record with this primary key):
     try
     {
       bool bTest = set_field_value_in_database(layout_field, field_value, primary_key_field, primary_key_value);
+
       //Glib::ustring strQuery = "UPDATE " + table_name;
       //strQuery += " SET " +  /* table_name + "." + postgres does not seem to like the table name here */ strFieldName + " = " + field.sql(field_value);
       //strQuery += " WHERE " + table_name + "." + primary_key_field.get_name() + " = " + primary_key_field.sql(primary_key_value);
@@ -651,12 +645,12 @@ void Box_Data_Details::refresh_related_fields(const Gtk::TreeModel::iterator& /*
         for(guint uiCol = 0; uiCol < cols_count; uiCol++)
         {
           const Gnome::Gda::Value value = result->get_value_at(uiCol, 0 /* row */);
-          const LayoutItem_Field& layout_item = *iterFields;
+          sharedptr<LayoutItem_Field> layout_item = *iterFields;
 
           //g_warning("list fill: field_name=%s", iterFields->get_name().c_str());
           //g_warning("  value_as_string=%s", value.to_string().c_str());
 
-          m_FlowTable.set_field_value(layout_item, value);
+          m_FlowTable.set_field_value(*layout_item, value);
 
           ++iterFields;
         }
@@ -706,7 +700,7 @@ void Box_Data_Details::on_userlevel_changed(AppState::userlevels user_level)
 bool Box_Data_Details::get_field_primary_key(Field& field) const
 {
   field = m_field_primary_key;
-  return false;
+  return true;
 }
 
 void Box_Data_Details::print_layout_group(xmlpp::Element* node_parent, const LayoutGroup& group)
@@ -729,11 +723,11 @@ void Box_Data_Details::print_layout_group(xmlpp::Element* node_parent, const Lay
       {
         xmlpp::Element* nodeField = nodeChildGroup->add_child("field");
 
-        nodeField->set_attribute("title", pLayoutField->m_field.get_title_or_name());
+        nodeField->set_attribute("title", pLayoutField->get_title_or_name());
 
         Gnome::Gda::Value value = m_FlowTable.get_field_value(*pLayoutField);
         Glib::ustring text_representation = GlomConversions::get_text_for_gda_value(pLayoutField->m_field.get_glom_type(), value,
-          pLayoutField->m_numeric_format); //In the current locale.
+          pLayoutField->get_formatting_used().m_numeric_format); //In the current locale.
 
         nodeField->set_attribute("value", text_representation);
       }
