@@ -278,7 +278,7 @@ void Dialog_Layout_Details::set_document(const Glib::ustring& layout, Document_G
       guint field_sequence = 1; //0 means no sequence
       for(type_vecLayoutFields::const_iterator iter = table_fields.begin(); iter != table_fields.end(); ++iter)
       {
-        LayoutItem_Field item = *iter;
+        LayoutItem_Field item = *(*iter);
         item.m_sequence = field_sequence;
 
         group.add_item(item, field_sequence);
@@ -897,7 +897,10 @@ void Dialog_Layout_Details::on_cell_data_name(Gtk::CellRenderer* renderer, const
 
       renderer_text->property_markup() = markup;
 
-      renderer_text->property_editable() = false; //Names can never be edited.
+      if(is_group)
+        renderer_text->property_editable() = true; //Group names can be changed.
+      else
+        renderer_text->property_editable() = false; //Field names can never be edited.
     }
   }
 }
