@@ -69,11 +69,11 @@ void Box_Tables::fill_table_row(const Gtk::TreeModel::iterator& iter, const Tabl
   }
 }
 
-void Box_Tables::fill_from_database()
+bool Box_Tables::fill_from_database()
 {
   Bakery::BusyCursor(*get_app_window());
 
-  Box_DB::fill_from_database();
+  bool result = Box_DB::fill_from_database();
 
   //Enable/Disable extra widgets:
   bool developer_mode = (get_userlevel() == AppState::USERLEVEL_DEVELOPER);
@@ -108,12 +108,13 @@ void Box_Tables::fill_from_database()
   //Get the list of hidden tables:
 
   Document_Glom::type_listTableInfo listTablesDocument;
-  if(m_pDocument)
+  Document_Glom* document = get_document();
+  if(document)
   {
-    listTablesDocument = m_pDocument->get_tables();
+    listTablesDocument = document->get_tables();
   }
   else
-    g_warning("Box_Tables::fill_from_database(): m_pDocument is null");
+    g_warning("Box_Tables::fill_from_database(): document is null");
 
   //Get the list of tables in the database, from the server:
   sharedptr<SharedConnection> sharedconnection = connect_to_server();
@@ -127,39 +128,46 @@ void Box_Tables::fill_from_database()
     for(type_vecStrings::iterator iter = vecTables.begin(); iter != vecTables.end(); iter++)
     {
       const Glib::ustring strName = *iter;
-
+     
+      TableInfo table_info;
+      
       //Check whether it should be hidden:
       Document_Glom::type_listTableInfo::iterator iterFind = std::find_if(listTablesDocument.begin(), listTablesDocument.end(), predicate_FieldHasName<TableInfo>(strName));
       if(iterFind != listTablesDocument.end())
       {
-        bool hidden = iterFind->m_hidden;
-
-        bool bAddIt = true;
-        if(hidden && !developer_mode)  //Don't add hidden tables unless we are in developer mode:
-          bAddIt = false;
-
-        if(hidden && !m_pCheckButtonShowHidden->get_active()) //Don't add hidden tables if that checkbox is unset.
-          bAddIt = false;
-
-        if(bAddIt)
-        {
-          Gtk::TreeModel::iterator iter = m_AddDel.add_item(strName);
-          fill_table_row(iter, *iterFind);
-        }
+        table_info = *iterFind;
       }
       else
       {
         //This table is in the database, but not in the document.
         //Show it as hidden:
-        if(developer_mode)
-        {
-          TableInfo table_info;
-          table_info.m_name = strName;
-          table_info.m_hidden = true;
+        table_info.m_name = strName;
+        table_info.m_hidden = true;
+      }
+      
+      bool hidden = iterFind->m_hidden;
 
-          Gtk::TreeModel::iterator iter = m_AddDel.add_item(strName);
-          fill_table_row(iter, table_info);
-        }
+      bool bAddIt = true;
+      if(hidden && !developer_mode)  //Don't add hidden tables unless we are in developer mode:
+        bAddIt = false;
+
+      if(hidden && !m_pCheckButtonShowHidden->get_active()) //Don't add hidden tables if that checkbox is unset.
+      {
+        bAddIt = false;
+      }
+      
+      //Check whether it's a system table, though they should never be in this list:
+      const Glib::ustring prefix = "glom_system_";
+      const Glib::ustring table_prefix = strName.substr(0, prefix.size());
+      if(table_prefix == prefix)
+      {
+        bAddIt = false;
+      }
+        
+      if(bAddIt)
+      {
+        Gtk::TreeModel::iterator iter = m_AddDel.add_item(strName);
+        fill_table_row(iter, table_info);
       }
     }
   }
@@ -168,17 +176,53 @@ void Box_Tables::fill_from_database()
 
   m_AddDel.set_allow_add(developer_mode);
   m_AddDel.set_allow_delete(developer_mode);
+
+  return result;
 }
 
 void Box_Tables::on_adddel_Add(const Gtk::TreeModel::iterator& row)
 {
   //TODO: Handle cell renderer changes to prevent illegal table names (e.g. starting with numbers.)"
-  
+
   Glib::ustring table_name = m_AddDel.get_value(row, m_colTableName);
   if(!table_name.empty())
   {
-    Glib::ustring primary_key_name =   table_name + "_id";
+    //Primary key:
+    Field field_primary_key;
+    field_primary_key.set_name(table_name + "_id");
+    field_primary_key.set_primary_key();
+    field_primary_key.set_auto_increment();
 
+    Gnome::Gda::FieldAttributes field_info = field_primary_key.get_field_info();
+    field_info.set_allow_null(false);
+    field_primary_key.set_field_info(field_info);
+
+    field_primary_key.set_glom_type(Field::TYPE_NUMERIC);
+
+    type_vecFields fields;
+    fields.push_back(field_primary_key);
+    
+    //Description:
+    Field field_description;
+    field_description.set_name("description");
+    field_description.set_title("Description");
+    field_description.set_glom_type(Field::TYPE_TEXT);
+    fields.push_back(field_description);
+    
+    //Comments:
+    Field field_comments;
+    field_comments.set_name("comments");
+    field_comments.set_title("Comments");
+    field_comments.set_glom_type(Field::TYPE_TEXT);
+    field_comments.m_default_formatting.set_text_format_multiline();
+    fields.push_back(field_comments);
+    
+    TableInfo table_info;
+    table_info.m_name = table_name;
+    table_info.m_title = util_title_from_string( table_name ); //Start with a title that might be appropriate.
+    
+    bool test = create_table(table_info, fields);
+    
     //Create a table with 1 "ID" field:
    //MSYQL:
     //Query_execute( "CREATE TABLE " + table_name + " (" + primary_key_name + " INT NOT NULL AUTO_INCREMENT PRIMARY KEY)" );
@@ -186,33 +230,30 @@ void Box_Tables::on_adddel_Add(const Gtk::TreeModel::iterator& row)
 
     //PostgresSQL:
     //Query_execute( "CREATE TABLE " + table_name + " (" + primary_key_name + " serial NOT NULL  PRIMARY KEY)" );
-    Query_execute( "CREATE TABLE \"" + table_name + "\" (" + primary_key_name + " numeric NOT NULL  PRIMARY KEY)" );
-
-    //Show the new information for this whole row:
-    TableInfo table_info;
-    table_info.m_name = table_name;
-    table_info.m_title = util_title_from_string( table_name ); //Start with a title that might be appropriate.
-    fill_table_row(row, table_info);
     
-    //Save the field information directly into the database, because we can not get all the correct information from the database.
-    //Otherwise some information would be forgotten:
-    Field field_primary_key;
-    Gnome::Gda::FieldAttributes field_info = field_primary_key.get_field_info();
-    field_info.set_name(primary_key_name);
-    field_info.set_primary_key();
-    field_info.set_auto_increment();
-    field_info.set_allow_null(false);
-    field_primary_key.set_field_info(field_info);
-    field_primary_key.set_glom_type(Field::TYPE_NUMERIC);
+    //Query_execute( "CREATE TABLE \"" + table_name + "\" (" +
+    //  field_primary_key.get_name() + " numeric NOT NULL  PRIMARY KEY," + 
+    //  extra_field_description + "varchar, " +
+    //  extra_field_comments + "varchar" +
+    //  ")" );
 
-    type_vecFields fields;
-    fields.push_back(field_primary_key);
-
-     if(m_pDocument)
-        m_pDocument->set_table_fields(table_name, fields);
-
-    save_to_document();
-    //fill_from_database(); //We should not modify the model structure in a cellrenderer signal handler.
+    if(test)
+    {
+      //Show the new information for this whole row:
+      fill_table_row(row, table_info);
+  
+      //Save the field information directly into the database, because we can not get all the correct information from the database.
+      //Otherwise some information would be forgotten:
+      
+  
+  
+      Document_Glom* document = get_document();
+      if(document)
+          document->set_table_fields(table_name, fields);
+  
+      save_to_document();
+      //fill_from_database(); //We should not modify the model structure in a cellrenderer signal handler.
+    }
   }
 }
 
@@ -228,10 +269,11 @@ void Box_Tables::on_adddel_Delete(const Gtk::TreeModel::iterator& rowStart, cons
 
     if(!table_name.empty())
     {
-      if(m_pDocument)
+      Document_Glom* document = get_document();
+      if(document)
       {
         //Don't open a table that the document does not know about, because we need information from the document:
-        if(!m_pDocument->get_table_is_known(table_name))
+        if(!document->get_table_is_known(table_name))
         {
            //TODO: Do not show tables that are not in the document.
            Gtk::MessageDialog dialog(_("You can not delete this table, because there is no information about this table in the document."));
@@ -251,7 +293,7 @@ void Box_Tables::on_adddel_Delete(const Gtk::TreeModel::iterator& rowStart, cons
           if(iButtonClicked == Gtk::RESPONSE_OK)
           {
             Query_execute( "DROP TABLE " + table_name);
-            m_pDocument->remove_table(table_name); //Forget about it in the document too.
+            get_document()->remove_table(table_name); //Forget about it in the document too.
             something_changed = true;
           }
         }
@@ -270,11 +312,12 @@ void Box_Tables::on_adddel_Delete(const Gtk::TreeModel::iterator& rowStart, cons
 void Box_Tables::on_adddel_Edit(const Gtk::TreeModel::iterator& row)
 {
   Glib::ustring table_name = m_AddDel.get_value_key(row);
-  
-  if(m_pDocument)
+
+  Document_Glom* document = get_document();
+  if(document)
   {
     //Don't open a table that the document does not know about, because we need information from the document:
-    if(!m_pDocument->get_table_is_known(table_name))
+    if(!document->get_table_is_known(table_name))
     {
        //TODO: Do not show tables that are not in the document.
        Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("Unknown Table")), true);
@@ -316,8 +359,9 @@ void Box_Tables::save_to_document()
       }
     }
 
-    if(m_pDocument)
-      m_pDocument->set_tables( listTables); //TODO: Don't save all new tables - just the ones already in the document.
+    Document_Glom* document = get_document();
+    if(document)
+      document->set_tables( listTables); //TODO: Don't save all new tables - just the ones already in the document.
   }
 }
 
